'use strict';

var state = require('@codemirror/state');
var vuuUtils = require('@vuu-ui/vuu-utils');

const NO_OPTIONS = {};
const applyWithCursorMove = () => (view, completion, from) => {
  const annotation = new state.AnnotationType();
  view.dispatch(
    {
      changes: { from, insert: completion.label },
      annotations: annotation.of(completion)
    },
    {
      changes: { from: from + 1, insert: " " },
      selection: { anchor: from + 2, head: from + 2 },
      annotations: annotation.of(completion)
    }
  );
};
const toSuggestions = (values, options = NO_OPTIONS) => {
  const {
    moveCursorToEnd = false,
    prefix = "",
    quoted = false,
    suffix = " ",
    isIllustration = false
  } = options;
  const quote = quoted ? '"' : "";
  return values.map((value) => ({
    isIllustration,
    label: value,
    apply: moveCursorToEnd ? applyWithCursorMove() : isIllustration ? `${quote}${prefix}${quote}` : `${prefix}${quote}${value}${quote}${suffix}`
  }));
};
const asNameSuggestion = { label: "as", apply: "as ", boost: 1 };
const booleanJoinSuggestions = [
  { label: "and", apply: "and ", boost: 5 },
  { label: "or", apply: "or ", boost: 3 }
];
const equalityOperators = [
  { label: "=", boost: 10, type: "operator" },
  { label: "!=", boost: 9, type: "operator" }
];
const stringOperators = [
  ...equalityOperators,
  { label: "in", boost: 6, type: "operator" },
  { label: "starts", boost: 5, type: "operator" },
  { label: "ends", boost: 4, type: "operator" }
];
const numericOperators = [
  ...equalityOperators,
  { label: ">", boost: 8, type: "operator" },
  { label: "<", boost: 7, type: "operator" }
];
const getRelationalOperators = (column) => {
  if (column === void 0 || vuuUtils.isNumericColumn(column)) {
    return numericOperators;
  } else {
    return equalityOperators;
  }
};
const getNamePrompt = (entity) => {
  const label = entity ? `enter name for this ${entity}` : "enter name";
  return [{ label, boost: 5 }];
};

exports.asNameSuggestion = asNameSuggestion;
exports.booleanJoinSuggestions = booleanJoinSuggestions;
exports.equalityOperators = equalityOperators;
exports.getNamePrompt = getNamePrompt;
exports.getRelationalOperators = getRelationalOperators;
exports.numericOperators = numericOperators;
exports.stringOperators = stringOperators;
exports.toSuggestions = toSuggestions;
//# sourceMappingURL=suggestion-utils.js.map
